@@ -45,7 +45,7 @@ regen:
   "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\">"LF\
   ""LF\
   "<head>"LF\
-  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\" />"LF\
+  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"LF\
   "	<meta name=\"description\" content=\"HTTrack is an easy-to-use website mirror utility. It allows you to download a World Wide website from the Internet to a local directory,building recursively all structures, getting html, images, and other files from the server to your computer. Links are rebuiltrelatively so that you can freely browse to the local site (works with any browser). You can mirror several sites together so that you can jump from one toanother. You can, also, update an existing mirror site, or resume an interrupted download. The robot is fully configurable, with an integrated help\" />"LF\
   "	<meta name=\"keywords\" content=\"httrack, HTTRACK, HTTrack, winhttrack, WINHTTRACK, WinHTTrack, offline browser, web mirror utility, aspirateur web, surf offline, web capture, www mirror utility, browse offline, local  site builder, website mirroring, aspirateur www, internet grabber, capture de site web, internet tool, hors connexion, unix, dos, windows 95, windows 98, solaris, ibm580, AIX 4.0, HTS, HTGet, web aspirator, web aspirateur, libre, GPL, GNU, free software\" />"LF\
   "	<title>Local index - HTTrack Website Copier</title>"LF\
@@ -204,7 +204,7 @@ regen:
   "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\">"LF\
   ""LF\
   "<head>"LF\
-  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\" />"LF\
+  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"LF\
   "	<meta name=\"description\" content=\"HTTrack is an easy-to-use website mirror utility. It allows you to download a World Wide website from the Internet to a local directory,building recursively all structures, getting html, images, and other files from the server to your computer. Links are rebuiltrelatively so that you can freely browse to the local site (works with any browser). You can mirror several sites together so that you can jump from one toanother. You can, also, update an existing mirror site, or resume an interrupted download. The robot is fully configurable, with an integrated help\" />"LF\
   "	<meta name=\"keywords\" content=\"httrack, HTTRACK, HTTrack, winhttrack, WINHTTRACK, WinHTTrack, offline browser, web mirror utility, aspirateur web, surf offline, web capture, www mirror utility, browse offline, local  site builder, website mirroring, aspirateur www, internet grabber, capture de site web, internet tool, hors connexion, unix, dos, windows 95, windows 98, solaris, ibm580, AIX 4.0, HTS, HTGet, web aspirator, web aspirateur, libre, GPL, GNU, free software\" />"LF\
   "	<title>List of available projects - HTTrack Website Copier</title>"LF\
@@ -356,7 +356,7 @@ regen:
   "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\">"LF\
   ""LF\
   "<head>"LF\
-  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\" />"LF\
+  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"LF\
   "	<meta name=\"description\" content=\"HTTrack is an easy-to-use website mirror utility. It allows you to download a World Wide website from the Internet to a local directory,building recursively all structures, getting html, images, and other files from the server to your computer. Links are rebuiltrelatively so that you can freely browse to the local site (works with any browser). You can mirror several sites together so that you can jump from one toanother. You can, also, update an existing mirror site, or resume an interrupted download. The robot is fully configurable, with an integrated help\" />"LF\
   "	<meta name=\"keywords\" content=\"httrack, HTTRACK, HTTrack, winhttrack, WINHTTRACK, WinHTTrack, offline browser, web mirror utility, aspirateur web, surf offline, web capture, www mirror utility, browse offline, local  site builder, website mirroring, aspirateur www, internet grabber, capture de site web, internet tool, hors connexion, unix, dos, windows 95, windows 98, solaris, ibm580, AIX 4.0, HTS, HTGet, web aspirator, web aspirateur, libre, GPL, GNU, free software\" />"LF\
   "	<title>Page not retrieved! - HTTrack Website Copier</title>"LF\
@@ -492,7 +492,7 @@ regen:
   "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\">"LF\
   ""LF\
   "<head>"LF\
-  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\" />"LF\
+  "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"LF\
   "	<meta name=\"description\" content=\"HTTrack is an easy-to-use website mirror utility. It allows you to download a World Wide website from the Internet to a local directory,building recursively all structures, getting html, images, and other files from the server to your computer. Links are rebuiltrelatively so that you can freely browse to the local site (works with any browser). You can mirror several sites together so that you can jump from one toanother. You can, also, update an existing mirror site, or resume an interrupted download. The robot is fully configurable, with an integrated help\" />"LF\
   "	<meta name=\"keywords\" content=\"httrack, HTTRACK, HTTrack, winhttrack, WINHTTRACK, WinHTTrack, offline browser, web mirror utility, aspirateur web, surf offline, web capture, www mirror utility, browse offline, local  site builder, website mirroring, aspirateur www, internet grabber, capture de site web, internet tool, hors connexion, unix, dos, windows 95, windows 98, solaris, ibm580, AIX 4.0, HTS, HTGet, web aspirator, web aspirateur, libre, GPL, GNU, free software\" />"LF\
   "	<title>Page not retrieved! - HTTrack Website Copier</title>"LF\
