@@ -17,18 +17,15 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-
 Important notes:
 
 - We hereby ask people using this source NOT to use it in purpose of grabbing
 emails addresses, or collecting any other private information on persons.
 This would disgrace our work, and spoil the many hours we spent on it.
 
-
 Please visit our Website: http://www.httrack.com
 */
 
-
 /* ------------------------------------------------------------ */
 /* File: Basic definitions                                      */
 /*       Used in .c files for basic (malloc() ..) definitions   */
@@ -71,9 +68,11 @@ extern "C" {
 #ifdef __GNUC__
 #define HTS_UNUSED __attribute__ ((unused))
 #define HTS_STATIC static __attribute__ ((unused))
+#define HTS_PRINTF_FUN(fmt, arg) __attribute__ ((format (printf, fmt, arg)))
 #else
 #define HTS_UNUSED
 #define HTS_STATIC static
+#define HTS_PRINTF_FUN(fmt, arg)
 #endif
 #endif
 
@@ -89,18 +88,16 @@ extern "C" {
 #define Sleep(a) { if (((a)*1000)%1000000) usleep(((a)*1000)%1000000); if (((a)*1000)/1000000) sleep(((a)*1000)/1000000); }
 #endif
 
-// teste galit de 2 chars, case insensitive
+// teste égalité de 2 chars, case insensitive
 #define hichar(a) ((((a)>='a') && ((a)<='z')) ? ((a)-('a'-'A')) : (a))
 #define streql(a,b) (hichar(a)==hichar(b))
 
-// caractre maj
+// caractère maj
 #define isUpperLetter(a) ( ((a) >= 'A') && ((a) <= 'Z') )
 
-
 /* Library internal definictions */
 #ifdef HTS_INTERNAL_BYTECODE
 
-
 // functions
 #ifdef _WIN32
 #define DynamicGet(handle, sym) GetProcAddress(handle, sym)
@@ -109,8 +106,8 @@ extern "C" {
 #endif
 
 // emergency log
-typedef void (*t_abortLog)(char* msg, char* file, int line);
-extern HTSEXT_API t_abortLog abortLog__;
+  typedef void (*t_abortLog) (char *msg, char *file, int line);
+  extern HTSEXT_API t_abortLog abortLog__;
 #define abortLog(a) abortLog__(a, __FILE__, __LINE__)
 #define _ ,
 #ifndef _WIN32_WCE
@@ -156,36 +153,6 @@ extern HTSEXT_API t_abortLog abortLog__;
   } \
 } while(0)
 
-/* logging */
-typedef enum {
-	LOG_DEBUG,
-	LOG_INFO,
-	LOG_WARNING,
-	LOG_ERROR,
-	LOG_PANIC
-} HTS_LogType;
-#define HTS_LOG(OPT,TYPE) do { \
-  int last_errno = errno; \
-	switch(TYPE) { \
-	case LOG_DEBUG: \
-		fspc(OPT,(OPT)->log, "debug"); \
-		break; \
-	case LOG_INFO: \
-		fspc(OPT,(OPT)->log, "info"); \
-		break; \
-	case LOG_WARNING: \
-		fspc(OPT,(OPT)->log, "warning"); \
-		break; \
-	case LOG_ERROR: \
-		fspc(OPT,(OPT)->log, "error"); \
-		break; \
-	case LOG_PANIC: \
-		fspc(OPT,(OPT)->log, "panic"); \
-		break; \
-	} \
-  errno = last_errno; \
-} while(0)
-
 /* regular malloc's() */
 #ifndef HTS_TRACE_MALLOC
 #define malloct(A)          malloc(A)
@@ -201,14 +168,14 @@ typedef enum {
 #define strdupt(A)    hts_strdup(A)
 #define freet(A)      do { hts_free(A); (A) = NULL; } while(0)
 #define realloct(A,B) hts_realloc(A,B)
-void  hts_freeall();
-void* hts_malloc    (size_t);
-void* hts_calloc(size_t,size_t);
-char* hts_strdup(char*);
-void* hts_xmalloc(size_t,size_t);
-void  hts_free      (void*);
-void* hts_realloc   (void*,size_t);
-mlink* hts_find(char* adr);
+  void hts_freeall();
+  void *hts_malloc(size_t);
+  void *hts_calloc(size_t, size_t);
+  char *hts_strdup(char *);
+  void *hts_xmalloc(size_t, size_t);
+  void hts_free(void *);
+  void *hts_realloc(void *, size_t);
+  mlink *hts_find(char *adr);
 /* protected memcpy */
 #define memcpybuff(A, B, N) do { \
   mlink* lnk = hts_find((void*)(A)); \
@@ -223,9 +190,9 @@ mlink* hts_find(char* adr);
 
 #endif
 
-typedef void (* htsErrorCallback)(char* msg, char* file, int line);
-extern HTSEXT_API htsErrorCallback htsCallbackErr;
-extern HTSEXT_API int htsMemoryFastXfr;
+  typedef void (*htsErrorCallback) (char *msg, char *file, int line);
+  extern HTSEXT_API htsErrorCallback htsCallbackErr;
+  extern HTSEXT_API int htsMemoryFastXfr;
 
 /*
 */
