@@ -17,18 +17,15 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-
 Important notes:
 
 - We hereby ask people using this source NOT to use it in purpose of grabbing
 emails addresses, or collecting any other private information on persons.
 This would disgrace our work, and spoil the many hours we spent on it.
 
-
 Please visit our Website: http://www.httrack.com
 */
 
-
 /* ------------------------------------------------------------ */
 /* File: htsmd5.c subroutines:                                  */
 /*       generate a md5 hash                                    */
@@ -48,34 +45,36 @@ Please visit our Website: http://www.httrack.com
 #include "htsmd5.h"
 #include "md5.h"
 
-int domd5mem(const char * buf, size_t len, char * digest, int asAscii) {
+int domd5mem(const char *buf, size_t len, char *digest, int asAscii) {
   int endian = 1;
   unsigned char bindigest[16];
   MD5_CTX ctx;
 
-  MD5Init(&ctx, * ( (char*) &endian));
-  MD5Update(&ctx, (const unsigned char*) buf, (unsigned int) len);
+  MD5Init(&ctx, *((char *) &endian));
+  MD5Update(&ctx, (const unsigned char *) buf, (unsigned int) len);
   MD5Final(bindigest, &ctx);
 
   if (!asAscii) {
     memcpy(digest, bindigest, 16);
   } else {
-    sprintf(digest, "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x"
-      "%02x%02x%02x%02x%02x",
-      bindigest[0],  bindigest[1],  bindigest[2],  bindigest[3],
-      bindigest[4],  bindigest[5],  bindigest[6],  bindigest[7],
-      bindigest[8],  bindigest[9],  bindigest[10], bindigest[11],
-      bindigest[12], bindigest[13], bindigest[14], bindigest[15]);
+    sprintf(digest,
+            "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x"
+            "%02x%02x%02x%02x%02x", bindigest[0], bindigest[1], bindigest[2],
+            bindigest[3], bindigest[4], bindigest[5], bindigest[6],
+            bindigest[7], bindigest[8], bindigest[9], bindigest[10],
+            bindigest[11], bindigest[12], bindigest[13], bindigest[14],
+            bindigest[15]);
   }
-  
+
   return 0;
 }
 
-unsigned long int md5sum32(const char* buff) {
+unsigned long int md5sum32(const char *buff) {
   union {
     char md5digest[16];
     unsigned long int hash;
   } u;
+
   domd5mem(buff, strlen(buff), u.md5digest, 0);
   return u.hash;
 }
